@@ -1,60 +1,90 @@
-( cd opt/kde/lib/kde3 ; rm -rf libabbrowserconduit.so )
-( cd opt/kde/lib/kde3 ; ln -sf libabbrowserconduit.so.0.0.0 libabbrowserconduit.so )
-( cd opt/kde/lib/kde3 ; rm -rf libabbrowserconduit.so.0 )
-( cd opt/kde/lib/kde3 ; ln -sf libabbrowserconduit.so.0.0.0 libabbrowserconduit.so.0 )
-( cd opt/kde/lib/kde3 ; rm -rf libexpenseconduit.so )
-( cd opt/kde/lib/kde3 ; ln -sf libexpenseconduit.so.0.0.0 libexpenseconduit.so )
-( cd opt/kde/lib/kde3 ; rm -rf libexpenseconduit.so.0 )
-( cd opt/kde/lib/kde3 ; ln -sf libexpenseconduit.so.0.0.0 libexpenseconduit.so.0 )
-( cd opt/kde/lib/kde3 ; rm -rf libknotesconduit.so )
-( cd opt/kde/lib/kde3 ; ln -sf libknotesconduit.so.0.0.0 libknotesconduit.so )
-( cd opt/kde/lib/kde3 ; rm -rf libknotesconduit.so.0 )
-( cd opt/kde/lib/kde3 ; ln -sf libknotesconduit.so.0.0.0 libknotesconduit.so.0 )
-( cd opt/kde/lib/kde3 ; rm -rf libnullconduit.so )
-( cd opt/kde/lib/kde3 ; ln -sf libnullconduit.so.0.0.0 libnullconduit.so )
 ( cd opt/kde/lib/kde3 ; rm -rf libnullconduit.so.0 )
 ( cd opt/kde/lib/kde3 ; ln -sf libnullconduit.so.0.0.0 libnullconduit.so.0 )
 ( cd opt/kde/lib/kde3 ; rm -rf libpopmailconduit.so )
 ( cd opt/kde/lib/kde3 ; ln -sf libpopmailconduit.so.0.0.0 libpopmailconduit.so )
-( cd opt/kde/lib/kde3 ; rm -rf libpopmailconduit.so.0 )
-( cd opt/kde/lib/kde3 ; ln -sf libpopmailconduit.so.0.0.0 libpopmailconduit.so.0 )
-( cd opt/kde/lib/kde3 ; rm -rf libtodoconduit.so )
-( cd opt/kde/lib/kde3 ; ln -sf libtodoconduit.so.0.0.0 libtodoconduit.so )
-( cd opt/kde/lib/kde3 ; rm -rf libtodoconduit.so.0 )
-( cd opt/kde/lib/kde3 ; ln -sf libtodoconduit.so.0.0.0 libtodoconduit.so.0 )
-( cd opt/kde/lib/kde3 ; rm -rf libvcalconduit.so )
-( cd opt/kde/lib/kde3 ; ln -sf libvcalconduit.so.0.0.0 libvcalconduit.so )
+( cd opt/kde/lib/kde3 ; rm -rf libtimeconduit.so.0 )
+( cd opt/kde/lib/kde3 ; ln -sf libtimeconduit.so.0.0.0 libtimeconduit.so.0 )
+( cd opt/kde/lib/kde3 ; rm -rf libaddressconduit.so.0 )
+( cd opt/kde/lib/kde3 ; ln -sf libaddressconduit.so.0.0.0 libaddressconduit.so.0 )
+( cd opt/kde/lib/kde3 ; rm -rf libexpenseconduit.so.0 )
+( cd opt/kde/lib/kde3 ; ln -sf libexpenseconduit.so.0.0.0 libexpenseconduit.so.0 )
+( cd opt/kde/lib/kde3 ; rm -rf libknotesconduit.so )
+( cd opt/kde/lib/kde3 ; ln -sf libknotesconduit.so.0.0.0 libknotesconduit.so )
 ( cd opt/kde/lib/kde3 ; rm -rf libvcalconduit.so.0 )
 ( cd opt/kde/lib/kde3 ; ln -sf libvcalconduit.so.0.0.0 libvcalconduit.so.0 )
-( cd opt/kde/lib ; rm -rf libkalarmd.so )
-( cd opt/kde/lib ; ln -sf libkalarmd.so.0.0.0 libkalarmd.so )
-( cd opt/kde/lib ; rm -rf libkalarmd.so.0 )
-( cd opt/kde/lib ; ln -sf libkalarmd.so.0.0.0 libkalarmd.so.0 )
-( cd opt/kde/lib ; rm -rf libkcal.so )
-( cd opt/kde/lib ; ln -sf libkcal.so.2.0.0 libkcal.so )
-( cd opt/kde/lib ; rm -rf libkcal.so.2 )
-( cd opt/kde/lib ; ln -sf libkcal.so.2.0.0 libkcal.so.2 )
-( cd opt/kde/lib ; rm -rf libkgantt.so )
-( cd opt/kde/lib ; ln -sf libkgantt.so.0.0.2 libkgantt.so )
-( cd opt/kde/lib ; rm -rf libkgantt.so.0 )
-( cd opt/kde/lib ; ln -sf libkgantt.so.0.0.2 libkgantt.so.0 )
+( cd opt/kde/lib/kde3 ; rm -rf libaddressconduit.so )
+( cd opt/kde/lib/kde3 ; ln -sf libaddressconduit.so.0.0.0 libaddressconduit.so )
+( cd opt/kde/lib/kde3 ; rm -rf libexpenseconduit.so )
+( cd opt/kde/lib/kde3 ; ln -sf libexpenseconduit.so.0.0.0 libexpenseconduit.so )
+( cd opt/kde/lib/kde3 ; rm -rf libnullconduit.so )
+( cd opt/kde/lib/kde3 ; ln -sf libnullconduit.so.0.0.0 libnullconduit.so )
+( cd opt/kde/lib/kde3 ; rm -rf libpopmailconduit.so.0 )
+( cd opt/kde/lib/kde3 ; ln -sf libpopmailconduit.so.0.0.0 libpopmailconduit.so.0 )
+( cd opt/kde/lib/kde3 ; rm -rf libvcalconduit.so )
+( cd opt/kde/lib/kde3 ; ln -sf libvcalconduit.so.0.0.0 libvcalconduit.so )
+( cd opt/kde/lib/kde3 ; rm -rf libtodoconduit.so )
+( cd opt/kde/lib/kde3 ; ln -sf libtodoconduit.so.0.0.0 libtodoconduit.so )
+( cd opt/kde/lib/kde3 ; rm -rf libknotesconduit.so.0 )
+( cd opt/kde/lib/kde3 ; ln -sf libknotesconduit.so.0.0.0 libknotesconduit.so.0 )
+( cd opt/kde/lib/kde3 ; rm -rf libtimeconduit.so )
+( cd opt/kde/lib/kde3 ; ln -sf libtimeconduit.so.0.0.0 libtimeconduit.so )
+( cd opt/kde/lib/kde3 ; rm -rf libtodoconduit.so.0 )
+( cd opt/kde/lib/kde3 ; ln -sf libtodoconduit.so.0.0.0 libtodoconduit.so.0 )
 ( cd opt/kde/lib ; rm -rf libkorganizer.so )
 ( cd opt/kde/lib ; ln -sf libkorganizer.so.1.0.0 libkorganizer.so )
-( cd opt/kde/lib ; rm -rf libkorganizer.so.1 )
-( cd opt/kde/lib ; ln -sf libkorganizer.so.1.0.0 libkorganizer.so.1 )
+( cd opt/kde/lib ; rm -rf libkcal.so.2 )
+( cd opt/kde/lib ; ln -sf libkcal.so.2.0.0 libkcal.so.2 )
+( cd opt/kde/lib ; rm -rf libknewstuff.so )
+( cd opt/kde/lib ; ln -sf libknewstuff.so.1.0.0 libknewstuff.so )
 ( cd opt/kde/lib ; rm -rf libkpilot.so )
 ( cd opt/kde/lib ; ln -sf libkpilot.so.0.0.0 libkpilot.so )
+( cd opt/kde/lib ; rm -rf libknewstuff.so.1 )
+( cd opt/kde/lib ; ln -sf libknewstuff.so.1.0.0 libknewstuff.so.1 )
+( cd opt/kde/lib ; rm -rf libkdepim.so )
+( cd opt/kde/lib ; ln -sf libkdepim.so.1.0.0 libkdepim.so )
+( cd opt/kde/lib ; rm -rf libkcalsystem.so.0 )
+( cd opt/kde/lib ; ln -sf libkcalsystem.so.0.0.1 libkcalsystem.so.0 )
+( cd opt/kde/lib ; rm -rf libkgantt.so )
+( cd opt/kde/lib ; ln -sf libkgantt.so.0.0.2 libkgantt.so )
+( cd opt/kde/lib ; rm -rf libkpimexchange.so )
+( cd opt/kde/lib ; ln -sf libkpimexchange.so.1.0.0 libkpimexchange.so )
+( cd opt/kde/lib ; rm -rf libksync.so )
+( cd opt/kde/lib ; ln -sf libksync.so.1.0.0 libksync.so )
+( cd opt/kde/lib ; rm -rf libkcal.so )
+( cd opt/kde/lib ; ln -sf libkcal.so.2.0.0 libkcal.so )
+( cd opt/kde/lib ; rm -rf libksync.so.1 )
+( cd opt/kde/lib ; ln -sf libksync.so.1.0.0 libksync.so.1 )
 ( cd opt/kde/lib ; rm -rf libkpilot.so.0 )
 ( cd opt/kde/lib ; ln -sf libkpilot.so.0.0.0 libkpilot.so.0 )
-( cd opt/kde/share/doc/HTML/en/kalarm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kalarm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kandy ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kandy ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/lib ; rm -rf libkpimexchange.so.1 )
+( cd opt/kde/lib ; ln -sf libkpimexchange.so.1.0.0 libkpimexchange.so.1 )
+( cd opt/kde/lib ; rm -rf libkalarmd.so.0 )
+( cd opt/kde/lib ; ln -sf libkalarmd.so.0.0.0 libkalarmd.so.0 )
+( cd opt/kde/lib ; rm -rf libkorganizer.so.1 )
+( cd opt/kde/lib ; ln -sf libkorganizer.so.1.0.0 libkorganizer.so.1 )
+( cd opt/kde/lib ; rm -rf libkgantt.so.0 )
+( cd opt/kde/lib ; ln -sf libkgantt.so.0.0.2 libkgantt.so.0 )
+( cd opt/kde/lib ; rm -rf libkcalsystem.so )
+( cd opt/kde/lib ; ln -sf libkcalsystem.so.0.0.1 libkcalsystem.so )
+( cd opt/kde/lib ; rm -rf libkalarmd.so )
+( cd opt/kde/lib ; ln -sf libkalarmd.so.0.0.0 libkalarmd.so )
+( cd opt/kde/lib ; rm -rf libkdepim.so.1 )
+( cd opt/kde/lib ; ln -sf libkdepim.so.1.0.0 libkdepim.so.1 )
 ( cd opt/kde/share/doc/HTML/en/karm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/karm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kdepim-apidocs ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kdepim-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kandy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kandy ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kaddressbook ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kalarmd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kalarm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kalarm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/knotes ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/knotes ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/korganizer ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/korganizer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kpilot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kpilot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/korganizer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/korganizer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
